==> zio-aws-xray_2.13-5.17.130.6-sources.jar: zio/aws/xray/model/DeleteSamplingRuleResponse.scala <==
package zio.aws.xray.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DeleteSamplingRuleResponse(
    samplingRuleRecord: Option[zio.aws.xray.model.SamplingRuleRecord] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.xray.model.DeleteSamplingRuleResponse = {
    import DeleteSamplingRuleResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.xray.model.DeleteSamplingRuleResponse
      .builder()
      .optionallyWith(samplingRuleRecord.map(value => value.buildAwsValue()))(
        _.samplingRuleRecord
      )
      .build()
  }
  def asReadOnly: zio.aws.xray.model.DeleteSamplingRuleResponse.ReadOnly =
    zio.aws.xray.model.DeleteSamplingRuleResponse.wrap(buildAwsValue())
}
object DeleteSamplingRuleResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.xray.model.DeleteSamplingRuleResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.xray.model.DeleteSamplingRuleResponse =
      zio.aws.xray.model.DeleteSamplingRuleResponse(
        samplingRuleRecord.map(value => value.asEditable)
      )
    def samplingRuleRecord
        : Option[zio.aws.xray.model.SamplingRuleRecord.ReadOnly]
    def getSamplingRuleRecord
        : ZIO[Any, AwsError, zio.aws.xray.model.SamplingRuleRecord.ReadOnly] =
      AwsError.unwrapOptionField("samplingRuleRecord", samplingRuleRecord)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.xray.model.DeleteSamplingRuleResponse
  ) extends zio.aws.xray.model.DeleteSamplingRuleResponse.ReadOnly {
    override val samplingRuleRecord
        : Option[zio.aws.xray.model.SamplingRuleRecord.ReadOnly] = scala
      .Option(impl.samplingRuleRecord())
      .map(value => zio.aws.xray.model.SamplingRuleRecord.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.xray.model.DeleteSamplingRuleResponse
  ): zio.aws.xray.model.DeleteSamplingRuleResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-xray_2.13-5.17.167.1-sources.jar: zio/aws/xray/model/DeleteSamplingRuleResponse.scala <==
package zio.aws.xray.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DeleteSamplingRuleResponse(
    samplingRuleRecord: Optional[zio.aws.xray.model.SamplingRuleRecord] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.xray.model.DeleteSamplingRuleResponse = {
    import DeleteSamplingRuleResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.xray.model.DeleteSamplingRuleResponse
      .builder()
      .optionallyWith(samplingRuleRecord.map(value => value.buildAwsValue()))(
        _.samplingRuleRecord
      )
      .build()
  }
  def asReadOnly: zio.aws.xray.model.DeleteSamplingRuleResponse.ReadOnly =
    zio.aws.xray.model.DeleteSamplingRuleResponse.wrap(buildAwsValue())
}
object DeleteSamplingRuleResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.xray.model.DeleteSamplingRuleResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.xray.model.DeleteSamplingRuleResponse =
      zio.aws.xray.model.DeleteSamplingRuleResponse(
        samplingRuleRecord.map(value => value.asEditable)
      )
    def samplingRuleRecord
        : Optional[zio.aws.xray.model.SamplingRuleRecord.ReadOnly]
    def getSamplingRuleRecord
        : ZIO[Any, AwsError, zio.aws.xray.model.SamplingRuleRecord.ReadOnly] =
      AwsError.unwrapOptionField("samplingRuleRecord", samplingRuleRecord)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.xray.model.DeleteSamplingRuleResponse
  ) extends zio.aws.xray.model.DeleteSamplingRuleResponse.ReadOnly {
    override val samplingRuleRecord
        : Optional[zio.aws.xray.model.SamplingRuleRecord.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.samplingRuleRecord())
        .map(value => zio.aws.xray.model.SamplingRuleRecord.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.xray.model.DeleteSamplingRuleResponse
  ): zio.aws.xray.model.DeleteSamplingRuleResponse.ReadOnly = new Wrapper(impl)
}
